timerelationtools.timespan_2_stops_before_timespan_1_starts
===========================================================

.. autofunction:: abjad.tools.timerelationtools.timespan_2_stops_before_timespan_1_starts.timespan_2_stops_before_timespan_1_starts
   :noindex:
